@@ -1,23 +1,12 @@
 /*
-  Copyright (c) 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-    Author: Allen Winter <allen.winter@kdab.com>
-  Copyright (C) 2014 Sergio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2010 Klarlvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Allen Winter <allen.winter@kdab.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+  SPDX-FileCopyrightText: 2014 Sergio Martins <iamsergio@gmail.com>
 
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 /**
   @file
   This file is part of the API for handling calendar data and provides
@@ -29,59 +18,58 @@
   @author Allen Winter \<winter@kde.org\>
 */
 #include "attachmenthandler.h"
-#include "calendarsupport_debug.h"
 #include "calendarsupport/utils.h"
+#include "calendarsupport_debug.h"
 
-#include <ItemFetchJob>
+#include <Akonadi/ItemFetchJob>
 
+#include <KIO/FileCopyJob>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
+#include <KIO/StatJob>
+#include <KJob>
+#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRun>
-#include <KIO/FileCopyJob>
-#include <KIO/StatJob>
-#include <KJobWidgets>
-#include <KJob>
 
-#include <QFileDialog>
-#include <QTemporaryFile>
-#include <QFile>
-#include <QPointer>
-#include <QMimeDatabase>
 #include <QDesktopServices>
+#include <QFile>
+#include <QFileDialog>
+#include <QMimeDatabase>
+#include <QPointer>
+#include <QTemporaryFile>
 
 using namespace KCalendarCore;
 using namespace Akonadi;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 struct ReceivedInfo {
     QString uid;
     QString attachmentName;
 };
 
-class Q_DECL_HIDDEN AttachmentHandler::Private
+class AttachmentHandlerPrivate
 {
 public:
-    Private(QWidget *parent)
+    explicit AttachmentHandlerPrivate(QWidget *parent)
         : mParent(parent)
     {
     }
 
     QMap<KJob *, ReceivedInfo> mJobToReceivedInfo;
-    QPointer<QWidget> mParent;
+    QPointer<QWidget> const mParent;
 };
 
-AttachmentHandler::AttachmentHandler(QWidget *parent) : QObject(parent)
-    , d(new Private(parent))
+AttachmentHandler::AttachmentHandler(QWidget *parent)
+    : QObject(parent)
+    , d(new AttachmentHandlerPrivate(parent))
 {
 }
 
-AttachmentHandler::~AttachmentHandler()
-{
-    delete d;
-}
+AttachmentHandler::~AttachmentHandler() = default;
 
-Attachment AttachmentHandler::find(const QString &attachmentName,
-                                   const Incidence::Ptr &incidence)
+Attachment AttachmentHandler::find(const QString &attachmentName, const Incidence::Ptr &incidence)
 {
     if (!incidence) {
         return Attachment();
@@ -103,28 +91,25 @@ Attachment AttachmentHandler::find(const QString &attachmentName,
     }
 
     if (a.isEmpty()) {
-        KMessageBox::error(
-            d->mParent,
-            i18n("No attachment named \"%1\" found in the incidence.", attachmentName));
+        KMessageBox::error(d->mParent, i18n("No attachment named \"%1\" found in the incidence.", attachmentName));
         return Attachment();
     }
 
     if (a.isUri()) {
-        auto job = KIO::stat(QUrl(a.uri()), KIO::StatJob::SourceSide, 0);
+        auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatBasic);
+
         KJobWidgets::setWindow(job, d->mParent);
         if (!job->exec()) {
             KMessageBox::sorry(
                 d->mParent,
-                i18n("The attachment \"%1\" is a web link that is inaccessible from this computer. ",
-                     QUrl::fromPercentEncoding(a.uri().toLatin1())));
+                i18n("The attachment \"%1\" is a web link that is inaccessible from this computer. ", QUrl::fromPercentEncoding(a.uri().toLatin1())));
             return Attachment();
         }
     }
     return a;
 }
 
-Attachment AttachmentHandler::find(const QString &attachmentName,
-                                   const ScheduleMessage::Ptr &message)
+Attachment AttachmentHandler::find(const QString &attachmentName, const ScheduleMessage::Ptr &message)
 {
     if (!message) {
         return Attachment();
@@ -132,10 +117,9 @@ Attachment AttachmentHandler::find(const QString &attachmentName,
 
     Incidence::Ptr incidence = message->event().dynamicCast<Incidence>();
     if (!incidence) {
-        KMessageBox::error(
-            d->mParent,
-            i18n("The calendar invitation stored in this email message is broken in some way. "
-                 "Unable to continue."));
+        KMessageBox::error(d->mParent,
+                           i18n("The calendar invitation stored in this email message is broken in some way. "
+                                "Unable to continue."));
         return Attachment();
     }
 
@@ -151,9 +135,7 @@ static QUrl tempFileForAttachment(const Attachment &attachment)
     QMimeDatabase db;
     QStringList patterns = db.mimeTypeForName(attachment.mimeType()).globPatterns();
     if (!patterns.empty()) {
-        s_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String(
-                                            "/attachementview_XXXXXX")
-                                        + patterns.first().remove(QLatin1Char('*')));
+        s_tempFile = new QTemporaryFile(QDir::tempPath() + QLatin1String("/attachementview_XXXXXX") + patterns.first().remove(QLatin1Char('*')));
     } else {
         s_tempFile = new QTemporaryFile();
     }
@@ -164,7 +146,7 @@ static QUrl tempFileForAttachment(const Attachment &attachment)
     s_tempFile->close();
     QFile tf(s_tempFile->fileName());
     if (tf.size() != attachment.size()) {
-        //whoops. failed to write the entire attachment. return an invalid URL.
+        // whoops. failed to write the entire attachment. return an invalid URL.
         delete s_tempFile;
         s_tempFile = nullptr;
         return url;
@@ -187,15 +169,13 @@ bool AttachmentHandler::view(const Attachment &attachment)
         // put the attachment in a temporary file and launch it
         QUrl tempUrl = tempFileForAttachment(attachment);
         if (tempUrl.isValid()) {
-            KRun::RunFlags flags;
-            flags |= KRun::DeleteTemporaryFiles;
-            flags |= KRun::RunExecutables;
-            stat = KRun::runUrl(tempUrl, attachment.mimeType(), nullptr, flags);
+            auto job = new KIO::OpenUrlJob(tempUrl, attachment.mimeType());
+            job->setDeleteTemporaryFile(true);
+            job->setRunExecutables(true);
+            job->start();
         } else {
             stat = false;
-            KMessageBox::error(
-                d->mParent,
-                i18n("Unable to create a temporary file for the attachment."));
+            KMessageBox::error(d->mParent, i18n("Unable to create a temporary file for the attachment."));
         }
         delete s_tempFile;
         s_tempFile = nullptr;
@@ -212,7 +192,7 @@ void AttachmentHandler::view(const QString &attachmentName, const QString &uid)
 {
     Item item;
     item.setGid(uid);
-    ItemFetchJob *job = new ItemFetchJob(item);
+    auto job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
     ReceivedInfo info;
     info.attachmentName = attachmentName;
@@ -228,9 +208,7 @@ bool AttachmentHandler::view(const QString &attachmentName, const ScheduleMessag
 bool AttachmentHandler::saveAs(const Attachment &attachment)
 {
     // get the saveas file name
-    const QString saveAsFile = QFileDialog::getSaveFileName(d->mParent, i18n(
-                                                                "Save Attachment"),
-                                                            attachment.label());
+    const QString saveAsFile = QFileDialog::getSaveFileName(d->mParent, i18n("Save Attachment"), attachment.label());
     if (saveAsFile.isEmpty()) {
         return false;
     }
@@ -251,9 +229,7 @@ bool AttachmentHandler::saveAs(const Attachment &attachment)
             }
         } else {
             stat = false;
-            KMessageBox::error(
-                d->mParent,
-                i18n("Unable to create a temporary file for the attachment."));
+            KMessageBox::error(d->mParent, i18n("Unable to create a temporary file for the attachment."));
         }
         delete s_tempFile;
         s_tempFile = nullptr;
@@ -270,7 +246,7 @@ void AttachmentHandler::saveAs(const QString &attachmentName, const QString &uid
 {
     Item item;
     item.setGid(uid);
-    ItemFetchJob *job = new ItemFetchJob(item);
+    auto job = new ItemFetchJob(item);
     connect(job, &ItemFetchJob::result, this, &AttachmentHandler::slotFinishView);
 
     ReceivedInfo info;
@@ -290,7 +266,7 @@ void AttachmentHandler::slotFinishSaveAs(KJob *job)
     bool success = false;
 
     if (job->error() != 0) {
-        ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
@@ -312,7 +288,7 @@ void AttachmentHandler::slotFinishView(KJob *job)
     bool success = false;
 
     if (job->error()) {
-        ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob *>(job);
+        auto fetchJob = qobject_cast<ItemFetchJob *>(job);
         const Item::List items = fetchJob->items();
         if (!items.isEmpty()) {
             Incidence::Ptr incidence = CalendarSupport::incidence(items.first());
