@@ -1,24 +1,8 @@
 /*
-  Copyright (c) 2009 KDAB
-  Author: Frank Osterfeld <frank@kdab.net>
+  SPDX-FileCopyrightText: 2009 KDAB
+  SPDX-FileContributor: Frank Osterfeld <frank@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "collectionselection.h"
@@ -28,28 +12,25 @@
 
 using namespace CalendarSupport;
 
-class Q_DECL_HIDDEN CollectionSelection::Private
+class CalendarSupport::CollectionSelectionPrivate
 {
 public:
-    explicit Private(QItemSelectionModel *model_) : model(model_)
+    explicit CollectionSelectionPrivate(QItemSelectionModel *model_)
+        : model(model_)
     {
     }
 
-    QItemSelectionModel *model = nullptr;
+    QItemSelectionModel *const model;
 };
 
 CollectionSelection::CollectionSelection(QItemSelectionModel *selectionModel, QObject *parent)
     : QObject(parent)
-    , d(new Private(selectionModel))
+    , d(new CollectionSelectionPrivate(selectionModel))
 {
-    connect(selectionModel, &QItemSelectionModel::selectionChanged, this,
-            &CollectionSelection::slotSelectionChanged);
+    connect(selectionModel, &QItemSelectionModel::selectionChanged, this, &CollectionSelection::slotSelectionChanged);
 }
 
-CollectionSelection::~CollectionSelection()
-{
-    delete d;
-}
+CollectionSelection::~CollectionSelection() = default;
 
 QItemSelectionModel *CollectionSelection::model() const
 {
