@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "freebusyitemmodel.h"
@@ -32,7 +19,8 @@ using namespace CalendarSupport;
 class ItemPrivateData
 {
 public:
-    ItemPrivateData(ItemPrivateData *parent) : parentItem(parent)
+    ItemPrivateData(ItemPrivateData *parent)
+        : parentItem(parent)
     {
     }
 
@@ -82,12 +70,6 @@ private:
 class CalendarSupport::FreeBusyItemModelPrivate
 {
 public:
-    FreeBusyItemModelPrivate()
-        : mForceDownload(false)
-        , mRootData(nullptr)
-    {
-    }
-
     ~FreeBusyItemModelPrivate()
     {
         delete mRootData;
@@ -108,8 +90,7 @@ FreeBusyItemModel::FreeBusyItemModel(QObject *parent)
     qRegisterMetaType<KCalendarCore::Period>("KCalendarCore::Period");
 
     Akonadi::FreeBusyManager *m = Akonadi::FreeBusyManager::self();
-    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this,
-            &FreeBusyItemModel::slotInsertFreeBusy);
+    connect(m, &Akonadi::FreeBusyManager::freeBusyRetrieved, this, &FreeBusyItemModel::slotInsertFreeBusy);
 
     connect(&d->mReloadTimer, &QTimer::timeout, this, &FreeBusyItemModel::autoReload);
     d->mReloadTimer.setSingleShot(true);
@@ -117,10 +98,7 @@ FreeBusyItemModel::FreeBusyItemModel(QObject *parent)
     d->mRootData = new ItemPrivateData(nullptr);
 }
 
-FreeBusyItemModel::~FreeBusyItemModel()
-{
-    delete d;
-}
+FreeBusyItemModel::~FreeBusyItemModel() = default;
 
 QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
 {
@@ -128,7 +106,7 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    ItemPrivateData *data = (ItemPrivateData *)index.internalPointer();
+    auto data = (ItemPrivateData *)index.internalPointer();
 
     if (data->parent() == d->mRootData) {
         int row = index.row();
@@ -160,9 +138,8 @@ QVariant FreeBusyItemModel::data(const QModelIndex &index, int role) const
     KCalendarCore::FreeBusyPeriod period = fbitem->freeBusy()->fullBusyPeriods().at(index.row());
     switch (role) {
     case Qt::DisplayRole: // return something to make modeltest happy
-        return QStringLiteral("%1 - %2").
-               arg(QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat),
-                   QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat));
+        return QStringLiteral("%1 - %2").arg(QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat),
+                                             QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat));
     case FreeBusyItemModel::FreeBusyPeriodRole:
         return QVariant::fromValue(period);
     default:
@@ -188,7 +165,7 @@ int FreeBusyItemModel::rowCount(const QModelIndex &parent) const
 
 int FreeBusyItemModel::columnCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return 1;
 }
 
@@ -219,7 +196,7 @@ QModelIndex FreeBusyItemModel::parent(const QModelIndex &child) const
         return QModelIndex();
     }
 
-    ItemPrivateData *childData = static_cast<ItemPrivateData *>(child.internalPointer());
+    auto childData = static_cast<ItemPrivateData *>(child.internalPointer());
     ItemPrivateData *parentData = childData->parent();
     if (parentData == d->mRootData) {
         return QModelIndex();
@@ -241,7 +218,7 @@ void FreeBusyItemModel::addItem(const FreeBusyItem::Ptr &freebusy)
     int row = d->mFreeBusyItems.size();
     beginInsertRows(QModelIndex(), row, row);
     d->mFreeBusyItems.append(freebusy);
-    ItemPrivateData *data = new ItemPrivateData(d->mRootData);
+    auto data = new ItemPrivateData(d->mRootData);
     d->mRootData->appendChild(data);
     endInsertRows();
 
@@ -252,14 +229,13 @@ void FreeBusyItemModel::addItem(const FreeBusyItem::Ptr &freebusy)
     updateFreeBusyData(freebusy);
 }
 
-void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent,
-                                           const KCalendarCore::FreeBusyPeriod::List &list)
+void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list)
 {
     if (!parent.isValid()) {
         return;
     }
 
-    ItemPrivateData *parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
+    auto parentData = static_cast<ItemPrivateData *>(parent.internalPointer());
     int fb_count = list.size();
     int childCount = parentData->childCount();
     QModelIndex first = index(0, 0, parent);
@@ -278,7 +254,7 @@ void FreeBusyItemModel::setFreeBusyPeriods(const QModelIndex &parent,
     } else if (fb_count > childCount) {
         beginInsertRows(parent, childCount, fb_count - 1);
         for (int i = childCount; i < fb_count; ++i) {
-            ItemPrivateData *childData = new ItemPrivateData(parentData);
+            auto childData = new ItemPrivateData(parentData);
             parentData->appendChild(childData);
         }
         endInsertRows();
@@ -364,7 +340,7 @@ void FreeBusyItemModel::updateFreeBusyData(const FreeBusyItem::Ptr &item)
 void FreeBusyItemModel::timerEvent(QTimerEvent *event)
 {
     killTimer(event->timerId());
-    for (FreeBusyItem::Ptr item : qAsConst(d->mFreeBusyItems)) {
+    for (FreeBusyItem::Ptr item : std::as_const(d->mFreeBusyItems)) {
         if (item->updateTimerID() == event->timerId()) {
             item->setUpdateTimerID(0);
             item->startDownload(d->mForceDownload);
@@ -385,7 +361,7 @@ void FreeBusyItemModel::slotInsertFreeBusy(const KCalendarCore::FreeBusy::Ptr &f
 
     fb->sortList();
 
-    for (FreeBusyItem::Ptr item : qAsConst(d->mFreeBusyItems)) {
+    for (FreeBusyItem::Ptr item : std::as_const(d->mFreeBusyItems)) {
         if (item->email() == email) {
             item->setFreeBusy(fb);
             const int row = d->mFreeBusyItems.indexOf(item);
@@ -404,7 +380,7 @@ void FreeBusyItemModel::autoReload()
 
 void FreeBusyItemModel::reload()
 {
-    for (FreeBusyItem::Ptr item : qAsConst(d->mFreeBusyItems)) {
+    for (FreeBusyItem::Ptr item : std::as_const(d->mFreeBusyItems)) {
         if (d->mForceDownload) {
             item->startDownload(d->mForceDownload);
         } else {
@@ -422,4 +398,3 @@ void FreeBusyItemModel::cancelReload()
 {
     d->mReloadTimer.stop();
 }
-
