@@ -1,34 +1,21 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Author: Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileContributor: Tobias Koenig <tokoe@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidenceviewer.h"
-#include "incidenceviewer_p.h"
 #include "attachmenthandler.h"
-#include "utils.h"
+#include "incidenceviewer_p.h"
 #include "urihandler.h"
+#include "utils.h"
 
 #include "incidenceattachmentmodel.h"
 
-#include <CollectionFetchJob>
-#include <ItemFetchScope>
 #include <Akonadi/Calendar/CalendarBase>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include <KCalUtils/IncidenceFormatter>
 
@@ -50,10 +37,8 @@ void TextBrowser::setSource(const QUrl &name)
     QString uri = name.toString();
     // QTextBrowser for some reason insists on putting // or / in links,
     // this is a crude workaround
-    if (uri.startsWith(QLatin1String("uid:"))
-        || uri.startsWith(QLatin1String("kmail:"))
-        || uri.startsWith(QStringLiteral("urn:x-ical").section(QLatin1Char(':'), 0, 0))
-        || uri.startsWith(QLatin1String("news:"))
+    if (uri.startsWith(QLatin1String("uid:")) || uri.startsWith(QLatin1String("kmail:"))
+        || uri.startsWith(QStringLiteral("urn:x-ical").section(QLatin1Char(':'), 0, 0)) || uri.startsWith(QLatin1String("news:"))
         || uri.startsWith(QLatin1String("mailto:"))) {
         uri.replace(QRegExp(QLatin1String("^([^:]+:)/+")), QStringLiteral("\\1"));
     }
@@ -65,15 +50,11 @@ void TextBrowser::setSource(const QUrl &name)
     }
 }
 
-class Q_DECL_HIDDEN IncidenceViewer::Private
+class CalendarSupport::IncidenceViewerPrivate
 {
 public:
-    Private(IncidenceViewer *parent)
-        : mCalendar(nullptr)
-        , mParent(parent)
-        , mParentCollectionFetchJob(nullptr)
-        , mAttachmentModel(nullptr)
-        , mDelayedClear(false)
+    explicit IncidenceViewerPrivate(IncidenceViewer *parent)
+        : mParent(parent)
     {
         mAttachmentHandler = new AttachmentHandler(parent);
         mBrowser = new TextBrowser;
@@ -87,9 +68,9 @@ public:
         QString text;
 
         if (mCurrentItem.isValid()) {
-            text = KCalUtils::IncidenceFormatter::extensiveDisplayStr(
-                CalendarSupport::displayName(mCalendar, mParentCollection),
-                CalendarSupport::incidence(mCurrentItem), mDate);
+            text = KCalUtils::IncidenceFormatter::extensiveDisplayStr(CalendarSupport::displayName(mCalendar, mParentCollection),
+                                                                      CalendarSupport::incidence(mCurrentItem),
+                                                                      mDate);
             text.prepend(mHeaderText);
             mBrowser->setHtml(text);
         } else {
@@ -106,8 +87,7 @@ public:
         mParentCollection = Akonadi::Collection();
 
         if (!job->error()) {
-            Akonadi::CollectionFetchJob *fetchJob
-                = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+            auto fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
             if (!fetchJob->collections().isEmpty()) {
                 mParentCollection = fetchJob->collections().at(0);
             }
@@ -118,13 +98,12 @@ public:
 
     void slotAttachmentUrlClicked(const QString &uri)
     {
-        const QString attachmentName
-            = QString::fromUtf8(QByteArray::fromBase64(uri.mid(7).toUtf8()));
+        const QString attachmentName = QString::fromUtf8(QByteArray::fromBase64(uri.mid(7).toUtf8()));
         mAttachmentHandler->view(attachmentName, CalendarSupport::incidence(mCurrentItem));
     }
 
     Akonadi::ETMCalendar *mCalendar = nullptr;
-    IncidenceViewer *mParent = nullptr;
+    IncidenceViewer *const mParent;
     TextBrowser *mBrowser = nullptr;
     Akonadi::Item mCurrentItem;
     QString mHeaderText;
@@ -139,7 +118,7 @@ public:
 
 IncidenceViewer::IncidenceViewer(Akonadi::ETMCalendar *calendar, QWidget *parent)
     : QWidget(parent)
-    , d(new Private(this))
+    , d(new IncidenceViewerPrivate(this))
 {
     d->mCalendar = calendar;
     init();
@@ -147,7 +126,7 @@ IncidenceViewer::IncidenceViewer(Akonadi::ETMCalendar *calendar, QWidget *parent
 
 IncidenceViewer::IncidenceViewer(QWidget *parent)
     : QWidget(parent)
-    , d(new Private(this))
+    , d(new IncidenceViewerPrivate(this))
 {
     d->mCalendar = nullptr;
     init();
@@ -155,7 +134,7 @@ IncidenceViewer::IncidenceViewer(QWidget *parent)
 
 void IncidenceViewer::init()
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     d->mBrowser->setOpenLinks(true);
@@ -170,10 +149,7 @@ void IncidenceViewer::init()
     d->updateView();
 }
 
-IncidenceViewer::~IncidenceViewer()
-{
-    delete d;
-}
+IncidenceViewer::~IncidenceViewer() = default;
 
 void IncidenceViewer::setCalendar(Akonadi::ETMCalendar *calendar)
 {
@@ -193,8 +169,7 @@ QDate IncidenceViewer::activeDate() const
 QAbstractItemModel *IncidenceViewer::attachmentModel() const
 {
     if (!d->mAttachmentModel) {
-        d->mAttachmentModel
-            = new IncidenceAttachmentModel(const_cast<IncidenceViewer *>(this));
+        d->mAttachmentModel = new IncidenceAttachmentModel(const_cast<IncidenceViewer *>(this));
     }
     return d->mAttachmentModel;
 }
@@ -214,7 +189,7 @@ void IncidenceViewer::setHeaderText(const QString &text)
     d->mHeaderText = text;
 }
 
-void IncidenceViewer::setIncidence(const Akonadi::Item &incidence, const QDate &date)
+void IncidenceViewer::setIncidence(const Akonadi::Item &incidence, QDate date)
 {
     d->mDate = date;
     ItemMonitor::setItem(incidence);
@@ -236,17 +211,13 @@ void IncidenceViewer::itemChanged(const Akonadi::Item &item)
     }
 
     if (d->mParentCollectionFetchJob) {
-        disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this,
-                   SLOT(slotParentCollectionFetched(KJob*)));
+        disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob *)), this, SLOT(slotParentCollectionFetched(KJob *)));
         delete d->mParentCollectionFetchJob;
     }
 
-    d->mParentCollectionFetchJob
-        = new Akonadi::CollectionFetchJob(d->mCurrentItem.parentCollection(),
-                                          Akonadi::CollectionFetchJob::Base, this);
+    d->mParentCollectionFetchJob = new Akonadi::CollectionFetchJob(d->mCurrentItem.parentCollection(), Akonadi::CollectionFetchJob::Base, this);
 
-    connect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this,
-            SLOT(slotParentCollectionFetched(KJob*)));
+    connect(d->mParentCollectionFetchJob, SIGNAL(result(KJob *)), this, SLOT(slotParentCollectionFetched(KJob *)));
 }
 
 void IncidenceViewer::itemRemoved()
